const fs = require('fs');
const path = require('path');
const AWS = require('aws-sdk');

const downloadsPath = path.join(process.env.HOME || process.env.USERPROFILE, 'Downloads');
const rootKeyFilePath = path.join(downloadsPath, 'rootkey.csv');

// Check if the rootkey.csv file exists
if (!fs.existsSync(rootKeyFilePath)) {
    console.error(`File not found: ${rootKeyFilePath}`);
    process.exit(1);
}

// Function to extract AWS credentials using regex
function extractAWSCredentials(filePath) {
    const fileContent = fs.readFileSync(filePath, 'utf8');
    const accessKeyIdMatch = fileContent.match(/Access key ID\s*,\s*([^,\s]+)/i);
    const secretAccessKeyMatch = fileContent.match(/Secret access key\s*,\s*([^,\s]+)/i);

    if (accessKeyIdMatch && secretAccessKeyMatch) {
        return {
            accessKeyId: accessKeyIdMatch[1],
            secretAccessKey: secretAccessKeyMatch[1],
        };
    } else {
        throw new Error('Failed to extract AWS credentials from rootkey.csv');
    }
}

function getPemFilesAndRegions() {
    const pemFiles = fs.readdirSync(downloadsPath).filter(file => file.endsWith('.pem'));
    const regions = new Set();

    pemFiles.forEach(file => {
        const match = file.match(/LightsailDefaultKey-(.*)\.pem/);
        if (match) {
            regions.add(match[1]);
        }
    });

    return Array.from(regions);
}

async function getLightsailInstances(region, credentials) {
    const lightsail = new AWS.Lightsail({
        region,
        accessKeyId: credentials.accessKeyId,
        secretAccessKey: credentials.secretAccessKey
    });

    try {
        const instances = await lightsail.getInstances({}).promise();
        return instances.instances;
    } catch (err) {
        console.error(`Error fetching instances in region ${region}:`, err.message);
        return [];
    }
}

async function main() {
    try {
        const credentials = extractAWSCredentials(rootKeyFilePath);
        console.log('AWS Credentials Loaded:', credentials); // Log loaded credentials for debugging
        const regions = getPemFilesAndRegions();

        if (regions.length === 0) {
            console.log('No regions found from .pem files.');
            return;
        }

        for (const region of regions) {
            console.log(`Fetching instances in region: ${region}`);
            const instances = await getLightsailInstances(region, credentials);

            if (instances.length === 0) {
                console.log(`No instances found in region: ${region}`);
            } else {
                instances.forEach(instance => {
                    console.log(`- Instance Name: ${instance.name}, State: ${instance.state.name}`);
                });
            }
        }
    } catch (error) {
        console.error('Error:', error.message);
    }
}

main().catch(console.error);
